about summary refs log tree commit diff stats
path: root/src/main.c
diff options
context:
space:
mode:
authorDaniel Santos <dacs.git@brilhante.top>2023-04-11 19:40:34 +0100
committerDaniel Santos <dan.git@brilhante.top>2023-07-01 10:06:43 +0100
commita4ca6291afe1e407b72b2ec03bffc595946071f3 (patch)
tree62a59e83f197497af240663fffc1f8a68991e008 /src/main.c
parentd049e91590af343327990a25dc3371adceb9d54b (diff)
downloadprofani-tty-a4ca6291afe1e407b72b2ec03bffc595946071f3.tar.gz
Profani-tty has reborn
Diffstat (limited to 'src/main.c')
-rw-r--r--src/main.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/main.c b/src/main.c
index 6edfd3c8..6c52f43e 100644
--- a/src/main.c
+++ b/src/main.c
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -55,7 +55,7 @@
 #include "plugins/python_plugins.h"
 #endif
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "common.h"
 #include "command/cmd_defs.h"
 
@@ -106,12 +106,12 @@ main(int argc, char** argv)
     if (version == TRUE) {
         if (strcmp(PACKAGE_STATUS, "development") == 0) {
 #ifdef HAVE_GIT_VERSION
-            g_print("Profanity, version %sdev.%s.%s\n", PACKAGE_VERSION, PROF_GIT_BRANCH, PROF_GIT_REVISION);
+            g_print("Profani-tty, version %sdev.%s.%s\n", PACKAGE_VERSION, PROF_GIT_BRANCH, PROF_GIT_REVISION);
 #else
-            g_print("Profanity, version %sdev\n", PACKAGE_VERSION);
+            g_print("Profani-tty, version %sdev\n", PACKAGE_VERSION);
 #endif
         } else {
-            g_print("Profanity, version %s\n", PACKAGE_VERSION);
+            g_print("Profani-tty, version %s\n", PACKAGE_VERSION);
         }
 
         // lets use fixed email instead of PACKAGE_BUGREPORT
@@ -5,20 +5,20 @@
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -5,20 +5,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -5,20 +5,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the